// node_modules/tsup/assets/esm_shims.js
import { fileURLToPath } from "url";
import path from "path";
var getFilename = () => fileURLToPath(import.meta.url);
var getDirname = () => path.dirname(getFilename());
var __dirname = /* @__PURE__ */ getDirname();

// src/index.ts
import * as fs from "fs";
import * as path2 from "path";
import * as Canvas from "canvas";
var { registerFont } = Canvas;
var ShareFont = class {
  constructor(id, name, path3) {
    let options = {
      id,
      name,
      path: path3,
      ShareFontOptions: {
        engine: "ShareImage.FontEngine",
        version: "v2.0.0"
      }
    };
    return options;
  }
};
var sirinStencil = new ShareFont("sirin-stencil", "Sirin Stencil", path2.join(__dirname, "..", "..", "assets", "fonts", "sirin-stencil.ttf"));
var arial = new ShareFont("arial", "Arial", path2.join(__dirname, "..", "..", "assets", "fonts", "arial.ttf"));
var defaultOptions = {
  tagline: "",
  titleFont: sirinStencil,
  taglineFont: arial,
  titleColor: "",
  imageWidth: 1280,
  imageHeight: 669,
  textLeftOffset: 480,
  titleBottomOffset: 254,
  textColor: "000000",
  titleFontSize: "64px",
  taglineFontSize: "48px"
};
function generateImage(src, title, output = { type: "base64" }, props = defaultOptions) {
  let _src = src;
  let _title = title;
  let _output = output;
  let {
    tagline = "",
    titleFont = sirinStencil,
    taglineFont = arial,
    titleColor = "",
    taglineColor,
    imageWidth = 1280,
    imageHeight = 669,
    textAreaWidth,
    textLeftOffset = 480,
    titleBottomOffset = 254,
    titleGravity,
    taglineGravity,
    textColor = "000000",
    titleFontSize = "64px",
    taglineFontSize = "48px"
  } = props;
  var _tagline = tagline, _titleFont = titleFont, _taglineFont = taglineFont, _titleColor = titleColor, _taglineColor = taglineColor, _imageWidth = imageWidth, _imageHeight = imageHeight, _textAreaWidth = textAreaWidth, _textLeftOffset = textLeftOffset, _titleBottomOffset = titleBottomOffset, _titleGravity = titleGravity, _taglineGravity = taglineGravity, _textColor = textColor, _titleFontSize = titleFontSize, _taglineFontSize = taglineFontSize;
  let img = new Canvas.Image();
  img.src = _src;
  return new Promise((resolve, reject) => {
    img.onload = () => {
      registerFont(_titleFont.path, { family: _titleFont.name });
      registerFont(_taglineFont.path, { family: _taglineFont.name });
      let canvas = Canvas.createCanvas(1280, 669);
      let ctx = canvas.getContext("2d");
      ctx.font = `${_titleFontSize} ${_titleFont.name}`;
      ctx.drawImage(img, 0, 0);
      ctx.fillText(_title, _textLeftOffset, _titleBottomOffset);
      ctx.font = `${_taglineFontSize} ${_taglineFont.name}`;
      ctx.fillText(_tagline, _textLeftOffset, 320);
      if (_output.type === "file") {
        let out = fs.createWriteStream(output.options.file.path);
        let stream = canvas.createPNGStream();
        stream.pipe(out);
        out.on("finish", () => {
          return;
        });
        return resolve(void 0);
      } else if (_output.type == "base64") {
        let buf = canvas.toBuffer("image/png");
        let b64 = buf.toString("base64");
        return resolve(b64);
      } else if (_output.type == "datauri") {
        let url = canvas.toDataURL();
        return resolve(url);
      } else if (_output.type == "buffer") {
        let buf = canvas.toBuffer("image/png");
        return resolve(buf);
      } else {
        let msg = { type: "ERROR", name: "UNSUPPORTED_TYPE", message: `The output type ${output.type} is not supported by ShareImage` };
        return resolve(msg);
      }
    };
  });
}
export {
  ShareFont,
  generateImage
};
